@@ -24,17 +24,21 @@
 #include <KLocalizedString>
 #include <KRun>
 #include <KShell>
-#include <KVBox>
-#include <KDialog>
 #include <KPluginFactory>
 
+#include <QDialog>
+#include <QDialogButtonBox>
 #include <QDir>
 #include <QLabel>
 #include <QPlainTextEdit>
 #include <QProcess>
+#include <QPushButton>
 #include <QString>
 #include <QStringList>
 #include <QTextStream>
+#include <QVBoxLayout>
+#include <KConfigGroup>
+#include <KWindowConfig>
 
 K_PLUGIN_FACTORY(FileViewSvnPluginFactory, registerPlugin<FileViewSvnPlugin>();)
 
@@ -89,6 +93,12 @@ FileViewSvnPlugin::FileViewSvnPlugin(QObject* parent, const QList<QVariant>& arg
     connect(m_removeAction, SIGNAL(triggered()),
             this, SLOT(removeFiles()));
 
+    m_revertAction = new QAction(this);
+    m_revertAction->setIcon(QIcon::fromTheme("document-revert"));
+    m_revertAction->setText(i18nc("@item:inmenu", "SVN Revert"));
+    connect(m_revertAction, SIGNAL(triggered()),
+            this, SLOT(revertFiles()));
+
     m_showUpdatesAction = new QAction(this);
     m_showUpdatesAction->setCheckable(true);
     m_showUpdatesAction->setText(i18nc("@item:inmenu", "Show SVN Updates"));
@@ -98,10 +108,10 @@ FileViewSvnPlugin::FileViewSvnPlugin(QObject* parent, const QList<QVariant>& arg
     connect(this, SIGNAL(setShowUpdatesChecked(bool)),
             m_showUpdatesAction, SLOT(setChecked(bool)));
 
-    connect(&m_process, SIGNAL(finished(int, QProcess::ExitStatus)),
-            this, SLOT(slotOperationCompleted(int, QProcess::ExitStatus)));
-    connect(&m_process, SIGNAL(error(QProcess::ProcessError)),
-            this, SLOT(slotOperationError()));
+    connect(&m_process, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
+            this, &FileViewSvnPlugin::slotOperationCompleted);
+    connect(&m_process, &QProcess::errorOccurred,
+            this, &FileViewSvnPlugin::slotOperationError);
 }
 
 FileViewSvnPlugin::~FileViewSvnPlugin()
@@ -152,6 +162,8 @@ bool FileViewSvnPlugin::beginRetrieval(const QString& directory)
             default:
                 if (filePath.contains('*')) {
                     version = UpdateRequiredVersion;
+                } else if (filePath.contains("W155010")) {
+                    version = UnversionedVersion;
                 }
                 break;
             }
@@ -201,15 +213,18 @@ KVersionControlPlugin::ItemVersion FileViewSvnPlugin::itemVersion(const KFileIte
     if (!item.isDir()) {
         // files that have not been listed by 'svn status' (= m_versionInfoHash)
         // are under version control per definition
-        return NormalVersion;
+        // NOTE: svn status does not report files in unversioned paths
+        const QString path = QFileInfo(itemUrl).path();
+        return m_versionInfoHash.value(path, NormalVersion);
     }
 
     // The item is a directory. Check whether an item listed by 'svn status' (= m_versionInfoHash)
     // is part of this directory. In this case a local modification should be indicated in the
     // directory already.
+    const QString itemDir = itemUrl + QDir::separator();
     QHash<QString, ItemVersion>::const_iterator it = m_versionInfoHash.constBegin();
     while (it != m_versionInfoHash.constEnd()) {
-        if (it.key().startsWith(itemUrl)) {
+        if (it.key().startsWith(itemDir)) {
             const ItemVersion version = m_versionInfoHash.value(it.key());
             if (version == LocallyModifiedVersion) {
                 return LocallyModifiedVersion;
@@ -224,11 +239,7 @@ KVersionControlPlugin::ItemVersion FileViewSvnPlugin::itemVersion(const KFileIte
 QList<QAction*> FileViewSvnPlugin::actions(const KFileItemList& items) const
 {
     if (items.count() == 1 && items.first().isDir()) {
-        QString directory = items.first().localPath();
-        if (!directory.endsWith(QLatin1Char('/'))) {
-            directory += QLatin1Char('/');
-        }
-        return directoryActions(directory);
+        return directoryActions(items.first());
     }
 
     foreach (const KFileItem& item, items) {
@@ -260,10 +271,12 @@ QList<QAction*> FileViewSvnPlugin::actions(const KFileItemList& items) const
         }
         m_commitAction->setEnabled(editingCount > 0);
         m_addAction->setEnabled(versionedCount == 0);
+        m_revertAction->setEnabled(editingCount == itemsCount);
         m_removeAction->setEnabled(versionedCount == itemsCount);
     } else {
         m_commitAction->setEnabled(false);
         m_addAction->setEnabled(false);
+        m_revertAction->setEnabled(false);
         m_removeAction->setEnabled(false);
     }
     m_updateAction->setEnabled(noPendingOperation);
@@ -273,6 +286,7 @@ QList<QAction*> FileViewSvnPlugin::actions(const KFileItemList& items) const
     actions.append(m_commitAction);
     actions.append(m_addAction);
     actions.append(m_removeAction);
+    actions.append(m_revertAction);
     actions.append(m_showUpdatesAction);
     return actions;
 }
@@ -299,21 +313,27 @@ void FileViewSvnPlugin::showLocalChanges()
 
 void FileViewSvnPlugin::commitFiles()
 {
-    KDialog dialog(0, Qt::Dialog);
+    QDialog dialog(0, Qt::Dialog);
 
-    KVBox* box = new KVBox(&dialog);
-    new QLabel(i18nc("@label", "Description:"), box);
-    QPlainTextEdit* editor = new QPlainTextEdit(box);
+    QWidget* boxWidget = new QWidget(&dialog);
+    QVBoxLayout* boxLayout = new QVBoxLayout(boxWidget);
 
-    dialog.setMainWidget(box);
-    dialog.setCaption(i18nc("@title:window", "SVN Commit"));
-    dialog.setButtons(KDialog::Ok | KDialog::Cancel);
-    dialog.setDefaultButton(KDialog::Ok);
-    dialog.setButtonText(KDialog::Ok, i18nc("@action:button", "Commit"));
+    boxLayout->addWidget(new QLabel(i18nc("@label", "Description:"),
+                                    boxWidget));
+    QPlainTextEdit* editor = new QPlainTextEdit(boxWidget);
+    boxLayout->addWidget(editor);
+
+    dialog.setWindowTitle(i18nc("@title:window", "SVN Commit"));
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    connect(buttonBox, &QDialogButtonBox::accepted, &dialog, &QDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, &dialog, &QDialog::reject);
+    auto okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setText(i18nc("@action:button", "Commit"));
 
     KConfigGroup dialogConfig(KSharedConfig::openConfig("dolphinrc"),
                               "SvnCommitDialog");
-    dialog.restoreDialogSize(dialogConfig);
+    KWindowConfig::restoreWindowSize(dialog.windowHandle(), dialogConfig);
 
     if (dialog.exec() == QDialog::Accepted) {
         // Write the commit description into a temporary file, so
@@ -338,7 +358,7 @@ void FileViewSvnPlugin::commitFiles()
                        i18nc("@info:status", "Committed SVN changes."));
     }
 
-    dialog.saveDialogSize(dialogConfig, KConfigBase::Persistent);
+    KWindowConfig::saveWindowSize(dialog.windowHandle(), dialogConfig, KConfigBase::Persistent);
 }
 
 void FileViewSvnPlugin::addFiles()
@@ -357,6 +377,14 @@ void FileViewSvnPlugin::removeFiles()
                    i18nc("@info:status", "Removed files from SVN repository."));
 }
 
+void FileViewSvnPlugin::revertFiles()
+{
+    execSvnCommand(QStringLiteral("revert"), QStringList(),
+                   i18nc("@info:status", "Reverting files from SVN repository..."),
+                   i18nc("@info:status", "Reverting of files from SVN repository failed."),
+                   i18nc("@info:status", "Reverted files from SVN repository."));
+}
+
 void FileViewSvnPlugin::slotOperationCompleted(int exitCode, QProcess::ExitStatus exitStatus)
 {
     m_pendingOperation = false;
@@ -385,7 +413,7 @@ void FileViewSvnPlugin::slotShowUpdatesToggled(bool checked)
     FileViewSvnPluginSettings* settings = FileViewSvnPluginSettings::self();
     Q_ASSERT(settings != 0);
     settings->setShowUpdates(checked);
-    settings->writeConfig();
+    settings->save();
 
     emit itemVersionsChanged();
 }
@@ -426,9 +454,12 @@ void FileViewSvnPlugin::startSvnCommandProcess()
     m_process.start(program, arguments);
 }
 
-QList<QAction*> FileViewSvnPlugin::directoryActions(const QString& directory) const
+QList<QAction*> FileViewSvnPlugin::directoryActions(const KFileItem& directory) const
 {
-    m_contextDir = directory;
+    m_contextDir = directory.localPath();
+    if (!m_contextDir.endsWith(QLatin1Char('/'))) {
+        m_contextDir += QLatin1Char('/');
+    }
     m_contextItems.clear();
 
     // Only enable the SVN actions if no SVN commands are
@@ -436,8 +467,10 @@ QList<QAction*> FileViewSvnPlugin::directoryActions(const QString& directory) co
     // startSvnCommandProcess()).
     const bool enabled = !m_pendingOperation;
     m_updateAction->setEnabled(enabled);
-    m_showLocalChangesAction->setEnabled(enabled);
-    m_commitAction->setEnabled(enabled);
+
+    const ItemVersion version = itemVersion(directory);
+    m_showLocalChangesAction->setEnabled(enabled && (version != NormalVersion));
+    m_commitAction->setEnabled(enabled && (version == LocallyModifiedVersion));
 
     QList<QAction*> actions;
     actions.append(m_updateAction);
